import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { interpolateYlOrRd, scaleSequential, max } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { Marks } from './Marks';
import { useCodes } from './useCodes';

const width = 960;
const height = 500;

const xaxisLabelOffset = 50;
const yaxisLabelOffset = 40;
const selectedYear = "2017";

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const codes = useCodes();
	
  if (!worldAtlas || !data || !codes) {
    return <pre>Loading...</pre>;
  }
 
  const numericCodeByAlphaCode = new Map();
  codes.forEach(code => {
    const alpha3Code = code["alpha-3"];
    const numericCode = code["country-code"];
  	numericCodeByAlphaCode.set(alpha3Code, numericCode);
  });

  
  const filteredData = data.filter(d => d.Year === selectedYear)
  
  const rowByCode = new Map();
  filteredData.forEach(d => {
    const alpha3Code = d.Code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
  	rowByCode.set(numericCode, d);
  });

  
  const colorValue = d => d.aids;
  
  const colorScale = scaleSequential(interpolateYlOrRd)  //Could not use schemeYlOrRd scheme is a descreet version instead should use interpolate version.
  	.domain([0, max(data, colorValue)]);

  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByCode={rowByCode}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
